% worksheet4_3
% Cross-coupling between two conductors routed over ground plane
clear
clc

% defining physical data
mo = 4*pi*1e-7 ; eo=8.854e-12; c=2.998e8; rho=1.7e-8;
h=1e-3;  s=4e-3; r=0.5e-3; len=1;
% calculating circuit parameters
Rss(1)=rho*len/(pi*r^2);
Rss(2)=0.005;
Rss(3)=Rss(1);
Fx=4*rho/(mo*pi*r^2);
Lc(1)=(mo*len/(2*pi))*log(2*h*s/(r*sqrt(s^2+4*h^2)));
Lc(2)=(mo*len/(2*pi))*log(sqrt(s^2+4*h^2)/s);
Lc(3)=Lc(1);
for i=1:3
    Cc(i)=(len/c)^2/Lc(i) ;
end
Fq = 1/(4*sqrt(Lc(1)*Cc(1)));

% components at near and far ends
Zn=[0 0 0];
Zf=[1e7 0 1e7]; 
Gc=[0 0 0];
% Voltage source of 1 Volt in loop 1
V = [ 1; 0; 0; 0];

n = 100 ;

% Transfer Admittance for open circuit terminations at far end
for s = 1:4*n ;
    f =  s*Fq/n ;
    Zb = Zbranch(f, Fx, Rss, Gc, Lc, Cc);
    ZL = Zloop( Zb, f, Zn, Zf) ;
    I = linsolve(ZL, V);
    Yoc(s) = abs(I(2));
    F(s) = f ;
end


% Transfer Admittance for short circuit terminations at far end
Zf=[0 0 0];
for s = 1:4*n ;
    f =  s*Fq/n ;
    Zb = Zbranch(f, Fx, Rss, Gc, Lc, Cc);
    ZL = Zloop( Zb, f, Zn, Zf) ;
    I = linsolve(ZL, V);
    Ysc(s) = abs(I(2));
    F(s) = f ;
end

% Transfer Admittance for critically damped line 
for i = 1:3
    Zf(i) = sqrt(Lc(i)/Cc(i));
end
for s = 1:4*n ;
    f =  s*Fq/n ;
    Zb = Zbranch(f, Fx, Rss, Gc, Lc, Cc);
    ZL = Zloop( Zb, f, Zn, Zf) ;
    I = linsolve(ZL, V);
    Ycr(s) = abs(I(2));
    F(s) = f ;
end

semilogy(F, Yoc, F, Ysc, F, Ycr)
title('Figure 4.3.6 Transfer Admittance; terminations open, shorted & damped')
xlabel('Frequency, Hz')
ylabel('Transfer Admittance')
    







