% worksheet6_6
% Transient emission model.
clear
clc

Rg=4.7; RL=1e7;
Vmeas=-0.41;
Crad=220e-12;
Rcable=1;
Ro1=50; Ro2=Ro1; Ro3=600;
Loss=Ro2/(Ro2+Ro3);
Ro=Ro1+Ro2*Ro3/(Ro2+Ro3);
ZT=2.27;
K=50/96.2;
Vg=Vmeas/K;
T=83e-9;
N=100;
dt=T/N;
T1=150e-9;
T2=4.1e-6;
T3=5e-6 ;
N1=T1/dt; N2=T2/dt; N3=T3/dt;

data=zeros(2,N);
near=[0 0];

% transmission line calculation
for i = 1:N3   
    Vgen=0;
    if  i>N1
        Vgen=Vg;
    end 
    if  i>N2
        Vgen=0;
    end
    p=point(i,N);
    Ifi=data(1,p);
    Ini=data(2,p);
    Ins=near(1);
    Qns=near(2);
    
    Ina=(2*Ro*Ini+Vgen-Rg*Ins)/(Rg+Ro+Rcable);
    Inr=Ina-Ini;
    Ine=Loss*Ina;
    Inf=Inr-Ine;
    Ins=Inf-Qns/(Ro*Crad);
    Int=Inf-Ins;
    Qns=Qns+Ins*dt;
    
    near(1)=Ins;
    near(2)=Qns;
    
    Ifa=2*Ro*Ifi/(RL+Ro);
    Ifr=Ifa-Ifi;
    
    data(1,p)=Int;
    data(2,p)=Ifr;
    
    Idiff=Ina-Ine;
    Vin=Vgen-Rg*(Ina+Ins);
    Vch1=K*Vin;
    Vdiff=ZT*Idiff;
    Vrad=ZT*Ine;
    
    Vout(i)=Vch1;
    time(i)= (i-1)*dt;
end

plot(time, Vout)  ;  
title('Figure 7.6.4 Simulated waveform of channel 1 input voltage.')
xlabel('Time, Seconds')
ylabel('Voltage, Volts') 


