% worksheet7_5
% Transmission line responses of cable and model
% data from test using setup of figure 7.5.1.
clear
clc

data1=[ 1       420     0.4 ;
        2       420     0.4 ;
        3       420     0.8 ;
        4       420     1.4 ;
        5       435     2.4 ;
        6       350     3.8 ;
        6.5     365     5.8 ;
        7       370     11  ;
        7.38	370     15  ;
        7.5     370     14  ;   
        7.7     365     11  ;
        8       365     7.6 ;
        9       365     3.6 ;
        10      360     2   ;
        11      360     1.8 ;
        12      360     1.8 ;
        13      360     1.8 ;
        14      355     1.6 ;
        15      360     1   ;
        16      375     2.6 ;
        17      320     2   ;
        18      270     1   ;
        19      280     1   ; 
        19.8	285     1]  ;
    
% data on circuit model of current transformer. See figure 7.2.7
R1=300; R2=51; R3=50; R4=850;
L1=200e-6; C1=60e-12; Turns=10;

% Admittance derived from test results from setup of fig.7.5.1, YTt
for s=1:length(data1);
    f1(s)=data1(s,1)*1e6;
    w=2*pi*f1(s);
    Vch1(s) = data1(s,2)*1e-3;
    Vin=((51+50)/50)*Vch1(s);
    Vch2(s) = data1(s,3)*1e-3 ;
    Z1=R4+1/(1j*w*C1);
    Y2=1/R1+1/R2+1/R3+1/(1j*w*L1)+1/Z1;
    Isec=abs(Y2)*Vch2(s);
    Iprim=Isec*Turns;
    YTt(s)=Iprim/Vin;
end

% plot(f1,YTt, 'r:o')
% hold on

data2=[ 1       420     2.8 ;
        2       420 	6.4 ;
        3       420     11  ;
        4       430     20.5;
        5       460     60  ;
        5.2     480     88  ;
        5.5     420     135 ;
        5.7     325		110 ;
        6       330     63.5;
        7       370     25  ;
        8       380     18.5;
        9       375     5.2 ;
        10      375     3.6 ;
        11      380     1.8 ;
        12      375     0.6 ;
        13      380     3   ;
        14      380     6.6 ;
        15      390     11.5;
        15.5	405     17  ;
        16      415     26  ;
        16.5	395     43  ;
        16.8	325     47  ;
        17      280     44  ;
        18      270     20  ;  
        19      290     11.5;
        19.8	295     8.2 ]   ;
    
% Admittance derived from test results from setup of fig.7.5.3, Yt
for s=1:length(data2);
    f2(s)=data2(s,1)*1e6;
    w=2*pi*f2(s);
    Vch1(s) = data2(s,2)*1e-3;
    Vin=((51+50)/50)*Vch1(s);
    Vch2(s) = data2(s,3)*1e-3 ;
    Z1=R4+1/(1j*w*C1);
    Y2=1/R1+1/R2+1/R3+1/(1j*w*L1)+1/Z1;
    Isec=abs(Y2)*Vch2(s);
    Iprim=Isec*Turns;
    Yt(s)=Iprim/Vin;
end

% plot(f2,Yt, 'b:o')

rho=1.7e-8; mo=4*pi*1e-7; mr=1;
r11=0.48e-3; r22=r11;
r12=1.95e-3;
len=7.5;
Ra=0.75;
Rss=[Ra, Ra, 0];
Fx=4*rho/(mo*pi*r11^2);
Lc(1)=mo*mr*len/(2*pi)*log(r12/r11);
Lc(2)=mo*mr*len/(2*pi)*log(r12/r22);
Lc(3)=mo*mr*len/(2*pi)*log(len/r12);
Rrad = 50;

eo=8.854e-12; c=3e8;
fqa=5.66e6;
va=4*len*fqa;
era=(c/va)^2;
fqb=7.55e6;
vb=4*len*fqb;
erb=(c/vb)^2;
Cc(1)=2*pi*eo*era*len/log(r12/r11);
Cc(2)=Cc(1);
Cc(3)=2*pi*eo*erb*len/log(len/r12);
    
Gc=[0,0,0];

V=[1; 0];

for i=1:200;
    f = i*1e5;
    Z = Zbranch(f, Fx, Rss, Gc, Lc, Cc );
    Z11 = 2*(Z(1,1)+Z(2,1)+Z(1,3)+Z(2,3))+Rrad;
    Z12 = -2*(Z(1,3)+Z(2,3))-Rrad;
    Z22 = 2*(Z(1,2)+Z(2,2)+Z(1,3)+Z(2,3))+Rrad;
    Zloop = [Z11 Z12;
             Z12 Z22];
    I = linsolve(Zloop, V);
    YTm(i) = abs(I(1)-I(2));
    Ym(i)= abs(I(2));
    F(i) = f ;
end

subplot(2,2,[1 2])
plot(F, YTm, f1,YTt, 'r:o') ;
axis([0 2e7 0 0.01]);
title('Figure 7.5.10 Radiated emission. Responses of cable and model.')
xlabel('Frequency, Hz')
ylabel('Transfer Admittance, Amps/Volt')

subplot(2,2,[3 4])
plot(F,Ym, f2, Yt, 'g:o');
title('Figure 7.5.11 Transmission line responses of cable and model.')
xlabel('Frequency, Hz')
ylabel('Admittance, Amps/Volt')





    
